@@ -1,19 +1,15 @@
 """Evolve a set of selected programs and a set of taxa representing the imparted knowledge.
 
-Description:
-    Initially, all programs in the tag database are selected, and the imparted knowledge is empty.
-
-    ..note::
-        As the filter evolves, the former set can only shrink, and the latter only increase.
-
-    The class stores the state of these two sets and provides a collection of operators to be
-    applied on them during the execution of the pipeline (see `paroxython.recommend_programs`).
-
-## Internal calls
+The class stores the state of these two sets and provides a collection of operators to be applied
+on them during the execution of the pipeline (see `paroxython.recommend_programs`). Two additional
+sets, less important, are maintained: the programs and the taxa to be hidden during the display of
+the final result.
 
 .. image:: resources/filter_flow.png
 
-
+.. note::
+    Initially, all programs in the tag database are selected. The three others sets are empty. As
+    the filter evolves, the first set can only shrink, and the other ones only increase.
 """
 
 from collections import Counter as counter
@@ -96,8 +92,8 @@ class ProgramFilter:
 
             ```
                             "operator/arithmetic/multiplication": [],
-                            "subroutine/argument/arg": [],
-                            "subroutine/procedure": [],
+                            "def/argument/arg": [],
+                            "def/procedure": [],
                             ...
             ```
 
@@ -105,13 +101,13 @@ class ProgramFilter:
             - The spans of the imported taxa are not copied, but replaced by an empty list (it is
             enough to know that a certain taxon is only featured by an imported program, not on
             which lines of which program).
-            - All imported taxa starting with `"metadata/"` are by convention excluded from the
+            - All imported taxa starting with `"meta/"` are by convention excluded from the
             copy.
         """
         for (exporter, importers) in self.db_exportations.items():
             exported_taxa = list(self.db_programs[exporter]["taxa"])
             for exported_taxon in exported_taxa:
-                if exported_taxon.startswith("metadata/"):
+                if exported_taxon.startswith("meta/"):
                     continue
                 for importer in importers:
                     importer_taxa = self.db_programs[importer]["taxa"]
@@ -234,11 +230,12 @@ class ProgramFilter:
         """
         if operation in ("impart", "hide"):
             patterns = [str(criterion) for criterion in criteria]
-            (program_set, taxon_set) = self.programs_and_taxa_of_patterns(patterns)
             if operation == "impart":
+                (program_set, taxon_set) = self.programs_and_taxa_of_patterns(patterns)
                 self.exclude_programs(program_set, follow=False)
                 self.impart_taxa(taxon_set)
             else:
+                (program_set, taxon_set) = self.programs_or_taxa_of_patterns(patterns)
                 self.hidden_programs.update(program_set)
                 self.hidden_taxa.update(taxon_set)
         else:
@@ -259,7 +256,8 @@ class ProgramFilter:
             Each pattern is a string which is interpreted either as:
 
             - a program name pattern (ending with `".py"`). All programs matching it are accumulated
-                in the result, along with any taxon they feature, directly or by importation;
+                in the result, _along with any taxon they feature, directly or by importation, this
+                being the only difference with `ProgramFilter.programs_or_taxa_of_patterns`_;
             - or a taxon name pattern. All taxa matching it are accumulated in the result.
 
         Args:
@@ -280,11 +278,24 @@ class ProgramFilter:
             resulting_taxa.update(taxa)
         return (resulting_programs, resulting_taxa)
 
+    def programs_or_taxa_of_patterns(
+        self, patterns: List[str]
+    ) -> Tuple[ProgramNameSet, TaxonNameSet]:
+        """See `ProgramFilter.programs_and_taxa_of_patterns`, minus the part in _italics_."""
+        resulting_taxa: TaxonNameSet = set()
+        resulting_programs: ProgramNameSet = set()
+        for pattern in patterns:
+            if pattern.endswith(".py"):
+                resulting_programs.update(self.programs_of_pattern(pattern))
+            else:
+                resulting_taxa.update(self.taxa_of_pattern(pattern))
+        return (resulting_programs, resulting_taxa)
+
     def programs_of_criteria(self, criteria: List[Criterion], follow: bool) -> Counter[ProgramName]:
-        """Calculate the set of programs that meet at least one of the criteria criteria.
+        """Calculate the set of programs that meet at least one of the criteria.
 
         Description:
-            Each criteria criterion may be either:
+            Each criterion may be either:
 
             - a string, which will be interpreted either as:
                 - a program name pattern (ending with `".py"`). All programs matching it are
@@ -545,9 +556,12 @@ class ProgramFilter:
 # "__init__" -> "add_imported_taxa"
 # "init_filter_state" -> "taxa_of_programs"  [style=invis]
 # "update_filter" -> "programs_and_taxa_of_patterns"
+# "update_filter" -> "programs_or_taxa_of_patterns"
 # "programs_and_taxa_of_patterns" -> "programs_of_pattern"
 # "programs_and_taxa_of_patterns" -> "taxa_of_programs"
 # "programs_and_taxa_of_patterns" -> "taxa_of_pattern"
+# "programs_or_taxa_of_patterns" -> "programs_of_pattern"
+# "programs_or_taxa_of_patterns" -> "taxa_of_pattern"
 # "update_filter" -> "programs_of_criteria"
 # "programs_of_criteria" -> "programs_of_pattern"
 # "programs_of_criteria" -> "programs_of_taxa"
