@@ -3,9 +3,9 @@ Translate labels into taxa.
 
 ## Description
 
-This translation comes after `paroxython.label_programs` has tagged a program with the **labels**
-defined in [`spec.md`](https://repo/paroxython/resources/spec.md). Its purpose is to convert these
-labels into the **taxa** defined (by default) in
+This step comes after `paroxython.label_programs` has tagged a program with the **labels** specified
+in [`spec.md`](https://repo/paroxython/resources/spec.md). Its purpose is to convert these labels
+into **taxa** based on the rules defined (by default) in
 [`taxonomy.tsv`](https://repo/paroxython/resources/taxonomy.tsv).
 
 ## Example
@@ -23,8 +23,8 @@ Let's return to the Jupyter notebook's cell given in the introduction:
 8       return result
 ```
 
-Note that the magic cell-command `%%paroxython` has now a `labels` argument. This produces the
-following output (limited to the first four rows):
+Note that the magic cell-command `%%paroxython` is now called with a `labels` argument. This
+produces the following output (limited for brevity to its first four rows):
 
 | Label | Lines |
 |:--|:--|
@@ -33,74 +33,26 @@ following output (limited to the first four rows):
 | `assignment_lhs_identifier:a` | 4, 7 |
 | `assignment_lhs_identifier:b` | 4, 7 |
 
-These labels are low-level tags, intended for internal use only. The tags of interest to the end
-user, the taxons, are calculated from these by the present module. Let us provide some examples of
-such translations.
+These labels are low-level tags, intended for internal use only. They still need to be translated
+into the following taxa, which are the only tags of interest to the end user. For instance,
+`"addition_operator"` will be translated into `"operator/arithmetic/addition"` (note that, unlike
+a label, a taxon may feature one or several slashes, which indicate the nesting of notions). More
+examples are given in the dedicated [section](docs_user_manual/index.html#taxonomy) of the user manual.
 
-### 1-1 mapping
+In fact, both labels and taxa are couples:
 
 - Label: `("addition_operator", [(7, 7, "...")])`.
 - Taxon: `("operator/arithmetic/addition", {(7, 7, "..."): 1})`.
 
-Note that, unlike a label, a taxon may feature one or several slashes, which indicate the nesting
-of notions. Taxa are relevant for the teacher precisely because they offer a first structuration of
-otherwise scattered knowledge.
+The second member is slightly more complicated than a list of line numbers:
 
-Both label and taxon are couples. The second member is slightly more complicated than a list of
-line numbers. For a label, it is a list of triples consisting of the start and end of the spanning
-lines, and a third member, the path, which identifies unambiguously the start of the span. For a
-taxon, it is a **bag**, i.e. a dictionary associating such triples with the count of their
-occurrences in the program. The paths being left untouched by the conversion, we will omit them
-from now on.
+- For a label, it is a list of triples consisting of the start and end of the spanning lines,
+and a third member, the path (here denoted by the ellipsis), which identifies unambiguously the
+start of the span.
+- For a taxon, it is a **bag**, i.e. a dictionary associating such triples with the count of their
+occurrences in the program.
 
-The actual conversion was done because the taxonomy contains the row:
-
-Taxa (replacement patterns)    | Labels (search patterns)
-:------------------------------|:-----------------------
-`operator/arithmetic/addition` | `addition_operator`
-
-This is the simplest case, where both taxon and label patterns are literal (they don't contain
-any metacharacter, more on that below).
-
-### 1-0 mapping
-
-- Label: `("binary_operator:Add", [(7, 7)])`.
-- Taxon: none.
-
-At first glance, the label `"binary_operator:Add"` may seem redundant with `"addition_operator"`,
-and one may wonder why it was generated at all. In fact, the former was used to calculate the
-latter.
-In [`spec.md`](https://repo/paroxython/resources/spec.md),
-the definition of `"addition_operator"` is introduced by these words: “An addition operator is a
-binary operator `Add` which has not be classified as a concatenation operator”.
-
-This is a good example of label for internal use only. In the present stage, it is simply ignored
-(i.e., it has no entry in the taxonomy).
-
-### 1-N mapping
-
-- Label: `("whole_span:8", [(2, 8)])`.
-- Taxa:
-    - `("metadata/program", {(2, 8): 1})`.
-    - `("metadata/sloc/8", {(2, 8): 1})`.
-
-This is an example of a label which produces two taxa. Although it is not obvious, both have their
-uses. The first one is common to all programs, and provides an invariable access key to an
-all-encompassing span. The second one has a variable part, and can be used to filter programs by
-[size](https://en.wikipedia.org/wiki/Source_lines_of_code) (for example, in
-`paroxython.recommend_programs`, the pattern `metadata/sloc/[1-5]` will be used to filter out the
-programs that have more than 5 lines).
-
-This conversions are triggered by the following rows in the default taxonomy:
-
-Taxa (replacement patterns)    | Labels (search patterns)
-:------------------------------|:-----------------------
-`metadata/program` | `whole_span:.+`
-`metadata/sloc/\1` | `whole_span:(.+)`
-
-Note that, in the replacement pattern, `"\1"` is a
-[_backreference_](https://docs.python.org/3/library/re.html#re.sub) to the first captured group
-(in parentheses).
+The paths being left untouched by the conversion, we will omit them from now on.
 
 ### Deduplication
 
@@ -110,9 +62,9 @@ Note that, in the replacement pattern, `"\1"` is a
     - `("parallel_assignment", [(4, 4), (7, 7)])`.
     - `("slide", [(7, 7)])`.
 - Taxa:
-    - `("variable/assignment/single", {(3, 3): 1})`.
-    - `("variable/assignment/parallel", {(4, 4): 1})`.
-    - `("variable/assignment/parallel/slide", {(7, 7): 1})`.
+    - `("var/assignment/single", {(3, 3): 1})`.
+    - `("var/assignment/parallel", {(4, 4): 1})`.
+    - `("var/assignment/parallel/slide", {(7, 7): 1})`.
 
 The example program features three distinct assignments. They can be categorized into:
 
@@ -129,26 +81,26 @@ Enter the taxa, whose production is triggered by the following taxonomy rows:
 
 Taxa (replacement patterns)    | Labels (search patterns)
 :------------------------------|:-----------------------
-`variable/assignment` | `assignment\b.*`
-`variable/assignment/parallel` | `parallel_assignment:\d+`
-`variable/assignment/parallel/slide` | `slide`
-`variable/assignment/single` | `single_assignment:.+`
+`var/assignment` | `assignment\b.*`
+`var/assignment/parallel` | `parallel_assignment:\d+`
+`var/assignment/parallel/slide` | `slide`
+`var/assignment/single` | `single_assignment:.+`
 
 Initially, the conversion produces as many redundant spans as for the labels:
 
 - Taxa:
-    - `("variable/assignment", {(3, 3): 1, (4, 4): 1, (7, 7): 1})`.
-    - `("variable/assignment/single", {(3, 3): 1})`.
-    - `("variable/assignment/parallel", {(4, 4): 1, (7, 7): 1})`.
-    - `("variable/assignment/parallel/slide", {(7, 7): 1})`.
+    - `("var/assignment", {(3, 3): 1, (4, 4): 1, (7, 7): 1})`.
+    - `("var/assignment/single", {(3, 3): 1})`.
+    - `("var/assignment/parallel", {(4, 4): 1, (7, 7): 1})`.
+    - `("var/assignment/parallel/slide", {(7, 7): 1})`.
 
 However, because of the tree-like structuring of taxa, it is possible to remove those occurrences
-that are subject to further characterization (e.g., `variable/assignment/parallel` on line 7 is
-further characterized as `variable/assignment/parallel/slide`), resulting in the list of taxa
+that are subject to further characterization (e.g., `var/assignment/parallel` on line 7 is
+further characterized as `var/assignment/parallel/slide`), resulting in the list of taxa
 given at the start of the section.
 
 Note that the removal of spans has finally led to the elimination of the overly generic taxon
-`variable/assignment`.
+`var/assignment`.
 """
 
 
@@ -180,12 +132,7 @@ __pdoc__ = {
 
 
 class Taxonomy:
-    def __init__(
-        self,
-        taxonomy_path: Optional[Path] = None,
-        is_literal: Callable = regex.compile(r"[\w:.]+").fullmatch,
-        **kwargs,
-    ) -> None:
+    def __init__(self, taxonomy_path: Optional[Path] = None, **kwargs,) -> None:
         r"""Read and pre-process the taxonomy specifications.
 
         Args:
@@ -193,24 +140,8 @@ class Taxonomy:
                 associating label (search) patterns with taxon (replacement) patterns. For better
                 readability, the taxa are listed on the first column, and the corresponding labels
                 (sometimes very long) on the second column. If not specified, the
-                [default taxonomy](https://repo/paroxython/resources/taxonomy.tsv)
-                is used. Defaults to `None`.
-            is_literal (Callable, optional): A predicate telling whether a given regular expression
-                pattern is literal or not. It will be matched successively against every label
-                pattern of the taxonomy TSV file (second column). For instance, the label pattern
-                `"external_free_call:print"` is literal, and then matches only itself. Conversely,
-                the label pattern `"internal_free_call:[[:upper:]].*"` contains some non-literal
-                characters such as `"["` and `"*"`, and then must be compiled into a regular
-                expression. By default, a pattern is considered to be literal if it contains only
-                letters, digits, underscores, hyphens, colons and **dots**.
-
-                ..note::
-                    The latter actually goes against the semantics of regular expressions. In case
-                    that's a problem, it is always possible to force the interpretation of a pattern
-                    as non-literal by enclosing it in parentheses.
-
-                [Not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
-                Defaults to `regex.compile(r"[\w:.]+").fullmatch`.
+                [default taxonomy](https://repo/paroxython/resources/taxonomy.tsv) is used.
+                Defaults to `None`.
 
         Description:
             1. Read the taxonomy, falling back to the provided default
@@ -237,7 +168,7 @@ class Taxonomy:
         self.literal_labels: Dict[LabelName, TaxonNames] = defaultdict(list)
         self.compiled_labels: List[Tuple[RegexPattern, TaxonPattern]] = []
         for line in sorted(tsv.split("\n")[1:]):
-            (taxon_value, label_value) = line.strip().split(maxsplit=1)
+            (taxon_value, label_value, *_) = line.strip().split(maxsplit=2)
             (taxon_pattern, label_pattern) = (TaxonPattern(taxon_value), LabelPattern(label_value))
             if is_literal(label_pattern):
                 self.literal_labels[LabelName(label_pattern)].append(TaxonName(taxon_pattern))
@@ -246,22 +177,26 @@ class Taxonomy:
                 # note: "$" is necessary: regex.fullmatch() has no regex.fullsub() counterpart
 
     @lru_cache(maxsize=None)
-    def get_taxon_name_list(self, label_name: LabelName) -> TaxonNames:
+    def get_taxon_name_list(
+        self, label_name: LabelName, looks_like_a_taxon: Callable = regex.compile(r"^\w+/.+$").match
+    ) -> TaxonNames:
         r"""Translate a label name into a list of taxon names.
 
         Description:
-            Most of the work was done during the initialization, by constructing the map
-            `self.literal_labels` and the list `self.compiled_labels`. The given label pattern is
+            First of all, when a label looks like a taxon, it is returned without further ado.
+
+            For the rest, most of the work was done during the initialization, by constructing the
+            map `self.literal_labels` and the list `self.compiled_labels`. The given label name is
             first looked up in the map, then matched successively against every regular expression
             stored in the list.
 
             The second step may be useful even if the first one has already produced one or several
-            translations. For instance, take a the taxonomy defining the following associations:
+            translations. For instance, take a taxonomy defining the following associations:
 
-            Taxa (replacement patterns)        | Labels (search patterns)
-            :----------------------------------|:-----------------------
-            `call/function/builtin/casting/\1` | `free_call:(list|dict)`
-            `type/sequence/list`               | `free_call:list`
+            Taxa (replacement patterns)         | Labels (search patterns)
+            :-----------------------------------|:-----------------------
+            `call/function/builtin/casting/\1`  | `free_call:(list|dict)`
+            `type/sequence/list`                | `free_call:list`
 
             Suppose now that we pass the label `"free_call:list"`. The lookup in the map produces
             a first translation: `"type/sequence/list"`. However, the linear search in the list
@@ -278,6 +213,8 @@ class Taxonomy:
             same label more than one time
             (cf. [lru_cache](https://docs.python.org/3/library/functools.html#functools.lru_cache)).
         """
+        if looks_like_a_taxon(label_name):
+            return [TaxonName(label_name)]
         result: TaxonNames = self.literal_labels.get(label_name, [])
         for (label_regex_pattern, taxon_pattern) in self.compiled_labels:
             if label_regex_pattern.match(label_name):
@@ -307,6 +244,24 @@ class Taxonomy:
         return deduplicated_taxa(taxa)
 
 
+def is_literal(label_pattern: LabelPattern) -> bool:
+    r"""Tell whether a given regular expression pattern is literal, disregarding the dots.
+
+    Description:
+        All label patterns of the taxonomy TSV file (second column) will be tested successively. For
+        instance, the label pattern `"external_free_call:print"` is literal, and then matches only
+        itself. Conversely, the label pattern `"internal_free_call:[[:upper:]].*"` contains some
+        non-literal characters such as `"["` and `"*"`, and then must be compiled into a regular
+        expression. A pattern is considered to be literal if it is equal to its escaped form, **not
+        taking the dots into account**.
+
+    ..note::
+        In case not considering the dot as a metacharacter is a  problem, it is always possible to
+        force the interpretation of a pattern as non-literal by enclosing it in parentheses.
+    """
+    return label_pattern.replace(".", "\\.") == regex.escape(label_pattern)
+
+
 def deduplicated_taxa(taxa: Taxa) -> Taxa:
     """Remove from the given taxa those that are counted multiple times as prefixes of another ones.
 
