@@ -4,9 +4,9 @@ from typing import Callable, Tuple
 
 import regex  # type: ignore
 
-from paroxython.compare_spans import compare_spans
-from paroxython.goodies import print_warning
-from paroxython.user_types import Predicate
+from .compare_spans import compare_spans
+from .goodies import print_warning
+from .user_types import Predicate
 
 
 def normalize_predicate(
@@ -26,7 +26,7 @@ def normalize_predicate(
         either by an exclamation mark prefix or the word “not”. In both cases, the negation marker
         is extracted from the given string.
 
-        The resulting string is then normalized, _i.e._ replaced by a key of the dictionary
+        The resulting string is then normalized, i.e. replaced by a key of the dictionary
         `compare_spans` defined in `paroxython.compare_spans`.
         .. include:: ../docs/md/pipeline_documentation.md
             :start-after: user input.
