@@ -7,11 +7,11 @@ the learning costs of its final state.
 The recommendation system is initialized with a database created by `paroxython.make_db`. It parses
 the given pipeline
 ([example](https://repo/examples/dummy/pipe.py)), checks
-its commands and submits them to the filter, which in response updates three sets:
+its commands and submits them to the filter, which in response updates these sets:
 
-- `selected_programs`, the recommended programs;
+- `selected_programs`, the names of the recommended programs;
 - `imparted_knowledge`, the taxa modelizing the imparted knowledge;
-- `hidden_taxa`, the taxa to be removed from the final output.
+- `hidden_programs`/`hidden_taxa`, the programs/taxa to be removed from the final output.
 
 When the pipeline is exhausted, it retrieves their values, compute the associated learning costs,
 and produces a Markdown report
@@ -66,8 +66,14 @@ class MalformedData(Exception):
 
 
 class Recommendations:
-    def __init__(self, db: JsonDatabase, base_path: Optional[Path] = None, **kwargs,) -> None:
-        """Initialize a recommendation system for the given database of programs tagged with taxa.
+    def __init__(
+        self,
+        db: JsonDatabase,
+        base_path: Optional[Path] = None,
+        title_format: str = "`{name}`",
+        **kwargs,
+    ) -> None:
+        r"""Initialize a recommendation system for the given database of programs tagged with taxa.
 
         Args:
             db (JsonDatabase): A Python dictionary containing the JSON structure constructed by
@@ -78,16 +84,19 @@ class Recommendations:
                 `exportations`, but ignores the field `labels`.
             base_path (Optional[Path], optional): A path, accessible from any optional shell command
                 under the name `"{base_path}"`. Defaults to `None`.
+            title_format (str): a string containing a substring `{name}` to be interpolated in
+                the final report with the relevant program's name. Defaults to `"\`{name}\`"`.
             **kwargs: May include the keyword argument `assessment_strategy`, transmitted to
                 `paroxython.assess_costs.LearningCostAssessor`.
 
         Warning:
             `db` is modified by side-effect. After initialization, the taxa of some programs have
             been augmented with the taxa of those they import, associated with an empty list of
-            spans. Exception: the taxa starting with `"metadata/"` are not imported.
+            spans. Exception: the taxa starting with `"meta/"` are not imported.
         """
 
         self.base_path = base_path
+        self.title_format = title_format
 
         # copy locally some attributes and methods of a ProgramFilter instance
         program_filter = ProgramFilter(db)
@@ -264,15 +273,17 @@ class Recommendations:
 
             for (cost, program_name) in costs_and_program_names:
                 program_info = self.db_programs[program_name]
-                title = f"Program `{program_name}` (learning cost {cost})"
-                toc.append(f"    - [`{program_name}`](#{title_to_slug(title)})")
+                program_title = self.title_format.format(name=program_name)
+                title = f"Program {program_title} (learning cost {cost})"
+                slug = title_to_slug(f"Program {program_name} (learning cost {cost})")
+                toc.append(f"    - [`{program_name}`](#{slug})")
                 contents.append(f"\n### {title}")
                 contents.append(f"\n```python\n{add_line_numbers(program_info['source'])}\n```")
                 contents.append("\n| Cost  | Taxon | Location |")
                 contents.append("|" + "----|" * 3)
                 items = sorted(
                     program_info["taxa"].items(),
-                    key=lambda x: f"~{x[0]}" if x[0].startswith("metadata/") else x[0],
+                    key=lambda x: f"~{x[0]}" if x[0].startswith("meta/") else x[0],
                 )
                 for (taxon_name, spans) in items:
                     if taxon_name in self.hidden_taxa:
